import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DyvCA8Nd.js";import{F as t,Ht as n,I as r,Lt as i,O as a,R as o,_t as s,et as c,it as l,j as u}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import{n as d}from"./vendor-i18n-NwyZMF0q.js";import"./i18n-B8CRKNXU.js";import"./vendor-reka-ui-Dfvl2gA8.js";import{t as f}from"./Button-uSZXZovG.js";import{t as p}from"./useExternalLink-Cxwyf6Kb.js";var m={class:`flex h-110 max-w-96 flex-col gap-4 p-2`},h={class:`mb-2 text-2xl font-medium`},g={class:`mb-4 text-base`},_={class:`flex items-center justify-between`},v={class:`flex gap-2`},y=o({__name:`ApiNodesSignInContent`,props:{apiNodeNames:{},onLogin:{type:Function},onCancel:{type:Function}},setup(e){let{t:o}=d(),{buildDocsUrl:y}=p(),handleLearnMoreClick=()=>{window.open(y(`/tutorials/api-nodes/faq`,{includeLocale:!0}),`_blank`)};return(e,d)=>{let p=l(`ApiNodesList`);return c(),u(`div`,m,[a(`div`,h,n(i(o)(`apiNodesSignInDialog.title`)),1),a(`div`,g,n(i(o)(`apiNodesSignInDialog.message`)),1),r(p,{"node-names":e.apiNodeNames},null,8,[`node-names`]),a(`div`,_,[r(f,{variant:`textonly`,onClick:handleLearnMoreClick},{default:s(()=>[t(n(i(o)(`g.learnMore`)),1)]),_:1}),a(`div`,v,[r(f,{variant:`secondary`,onClick:d[0]||=t=>e.onCancel?.()},{default:s(()=>[t(n(i(o)(`g.cancel`)),1)]),_:1}),r(f,{onClick:d[1]||=t=>e.onLogin?.()},{default:s(()=>[t(n(i(o)(`g.login`)),1)]),_:1})])])])}}});export{y as default};
//# sourceMappingURL=ApiNodesSignInContent-C3bUM3Iv.js.map