import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DyvCA8Nd.js";import"./vendor-firebase-yTFzdAQf.js";import{F as t,Ht as n,I as r,Lt as i,O as a,R as o,_t as s,et as c,j as l}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import"./useFeatureFlags-BfqxvwHy.js";import"./api-C840HmAF.js";import"./vendor-markdown-8POvMhty.js";import"./colorUtil-Q3kaA72Z.js";import"./i18n-B8CRKNXU.js";import"./vendor-reka-ui-Dfvl2gA8.js";import{t as u}from"./Button-uSZXZovG.js";import{Kr as d,vr as f}from"./dialogService-J-k0CeI4.js";import"./systemStatsStore-BJOd4X3d.js";import"./userStore-o2bxxBJt.js";import"./useErrorHandling-t4kNWELW.js";import"./vendor-tiptap-BZCaYoPl.js";import"./Popover-BV6_S20i.js";import"./markdownRendererUtil-DH1PCfUd.js";import"./useExternalLink-Cxwyf6Kb.js";var p={class:`flex w-full max-w-[512px] flex-col rounded-2xl border border-border-default bg-base-background`},m={class:`flex h-12 items-center justify-between border-b border-border-default px-4`},h={class:`m-0 text-sm font-normal text-base-foreground`},g=[`aria-label`],_={class:`flex flex-col gap-4 px-4 py-4`},v={class:`m-0 text-sm text-muted-foreground`},y={class:`flex items-center justify-end gap-4 px-4 py-4`},b=o({__name:`InviteMemberUpsellDialogContent`,setup(e){let o=d(),{isActiveSubscription:b,showSubscriptionDialog:x}=f();function onDismiss(){o.closeDialog({key:`invite-member-upsell`})}function onUpgrade(){o.closeDialog({key:`invite-member-upsell`}),x()}return(e,o)=>(c(),l(`div`,p,[a(`div`,m,[a(`h2`,h,n(i(b)?e.$t(`workspacePanel.inviteUpsellDialog.titleSingleSeat`):e.$t(`workspacePanel.inviteUpsellDialog.titleNotSubscribed`)),1),a(`button`,{class:`cursor-pointer rounded border-none bg-transparent p-0 text-muted-foreground transition-colors hover:text-base-foreground focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-secondary-foreground`,"aria-label":e.$t(`g.close`),onClick:onDismiss},o[0]||=[a(`i`,{class:`pi pi-times size-4`},null,-1)],8,g)]),a(`div`,_,[a(`p`,v,n(i(b)?e.$t(`workspacePanel.inviteUpsellDialog.messageSingleSeat`):e.$t(`workspacePanel.inviteUpsellDialog.messageNotSubscribed`)),1)]),a(`div`,y,[r(u,{variant:`muted-textonly`,onClick:onDismiss},{default:s(()=>[t(n(e.$t(`g.cancel`)),1)]),_:1}),r(u,{variant:`primary`,size:`lg`,onClick:onUpgrade},{default:s(()=>[t(n(i(b)?e.$t(`workspacePanel.inviteUpsellDialog.upgradeToCreator`):e.$t(`workspacePanel.inviteUpsellDialog.viewPlans`)),1)]),_:1})])]))}});export{b as default};
//# sourceMappingURL=InviteMemberUpsellDialogContent-DLhl9pXL.js.map