import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{i as t,it as n,n as r,r as i,w as a}from"./vendor-primevue-DyvCA8Nd.js";import{A as o,D as s,F as c,Ht as l,I as u,Lt as d,O as f,R as p,_t as m,et as h,j as g,k as _}from"./vendor-vue-core-IZuWV8u3.js";import{K as v}from"./vendor-vueuse-ChbGLbpR.js";import{n as y}from"./vendor-i18n-NwyZMF0q.js";import{t as b}from"./Button-uSZXZovG.js";import{Dr as x}from"./dialogService-J-k0CeI4.js";import{r as S}from"./signInSchema-BMYA3BDA.js";import{t as C}from"./PasswordFields-D0_uh31-.js";var w={class:`mb-2 text-base font-medium opacity-80`,for:`comfy-org-sign-up-email`},T={key:0,class:`text-red-500`},E=p({__name:`SignUpForm`,emits:[`submit`],setup(e,{emit:p}){let{t:E}=y(),D=x(),O=s(()=>D.loading),k=p,A=v(e=>{e.valid&&k(`submit`,e.values)},1500);return(e,s)=>(h(),_(d(t),{class:`flex flex-col gap-6`,resolver:d(r)(d(S)),onSubmit:d(A)},{default:m(e=>[u(d(i),{name:`email`,class:`flex flex-col gap-2`},{default:m(e=>[f(`label`,w,l(d(E)(`auth.signup.emailLabel`)),1),u(d(n),{"pt:root:id":`comfy-org-sign-up-email`,"pt:root:autocomplete":`email`,class:`h-10`,type:`text`,placeholder:d(E)(`auth.signup.emailPlaceholder`),invalid:e.invalid},null,8,[`placeholder`,`invalid`]),e.error?(h(),g(`small`,T,l(e.error.message),1)):o(``,!0)]),_:1}),u(C),O.value?(h(),_(d(a),{key:0,class:`mx-auto h-8 w-8`})):(h(),_(b,{key:1,type:`submit`,class:`mt-4 h-10 font-medium`,disabled:!e.valid},{default:m(()=>[c(l(d(E)(`auth.signup.signUpButton`)),1)]),_:2},1032,[`disabled`]))]),_:1},8,[`resolver`,`onSubmit`]))}});export{E as t};
//# sourceMappingURL=SignUpForm-fN2TxV1T.js.map