import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DyvCA8Nd.js";import"./vendor-firebase-yTFzdAQf.js";import{D as t,Lt as n,R as r,et as i,k as a,ot as o}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import"./useFeatureFlags-BfqxvwHy.js";import"./api-C840HmAF.js";import"./vendor-markdown-8POvMhty.js";import"./colorUtil-Q3kaA72Z.js";import"./i18n-B8CRKNXU.js";import"./vendor-reka-ui-Dfvl2gA8.js";import"./Button-uSZXZovG.js";import{vr as s}from"./dialogService-J-k0CeI4.js";import"./systemStatsStore-BJOd4X3d.js";import"./userStore-o2bxxBJt.js";import"./useErrorHandling-t4kNWELW.js";import"./vendor-tiptap-BZCaYoPl.js";import"./Popover-BV6_S20i.js";import"./markdownRendererUtil-DH1PCfUd.js";import"./useExternalLink-Cxwyf6Kb.js";import{t as c}from"./ComfyQueueButton-DLTOLV5u.js";import{t as l}from"./SubscribeToRun-t6EmLBLg.js";var u=r({__name:`CloudRunButtonWrapper`,setup(e){let{isActiveSubscription:r}=s(),u=t(()=>r.value?c:l);return(e,t)=>(i(),a(o(u.value),{key:n(r)?`queue`:`subscribe`}))}});export{u as default};
//# sourceMappingURL=CloudRunButtonWrapper-CIT8ZRzh.js.map