import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{A as t,s as n}from"./vendor-primevue-DyvCA8Nd.js";import{A as r,D as i,G as a,Ht as o,I as s,K as c,Lt as l,R as u,_t as d,b as f,et as p,j as m,k as h,lt as g,ut as _,zt as v}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import{t as y}from"./src-B0kocU_l.js";import{r as b}from"./widgetTypes-C7uVk06B.js";import{o as x,r as S}from"./widgetPropFilter-BW8CLrhL.js";import{t as C}from"./layout--1YiVcXi.js";var w=[`for`],T=u({__name:`WidgetTextarea`,props:a({widget:{},placeholder:{default:``}},{modelValue:{default:``},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let a=_(e,`modelValue`),u=b(),T=i(()=>x(e.widget.options,S)),E=i(()=>e.widget.label||e.widget.name),D=g(),O=i(()=>e.widget.options?.read_only??e.widget.options?.disabled??!1);return(e,i)=>(p(),h(l(t),{variant:`in`,unstyled:l(u),class:v(l(y)(`rounded-lg space-y-1 focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all`,e.widget.borderStyle))},{default:d(()=>[s(l(n),c(T.value,{id:l(D),modelValue:a.value,"onUpdate:modelValue":i[0]||=e=>a.value=e,class:l(y)(l(C),`size-full text-xs resize-none`),placeholder:e.placeholder,readonly:O.value,fluid:``,"data-capture-wheel":`true`,onPointerdownCapture:i[1]||=f(()=>{},[`stop`]),onPointermoveCapture:i[2]||=f(()=>{},[`stop`]),onPointerupCapture:i[3]||=f(()=>{},[`stop`]),onContextmenuCapture:i[4]||=f(()=>{},[`stop`])}),null,16,[`id`,`modelValue`,`class`,`placeholder`,`readonly`]),l(u)?r(``,!0):(p(),m(`label`,{key:0,for:l(D)},o(E.value),9,w))]),_:1},8,[`unstyled`,`class`]))}});export{T as default};
//# sourceMappingURL=WidgetTextarea-69J5kHoL.js.map