import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DyvCA8Nd.js";import"./vendor-firebase-yTFzdAQf.js";import{A as t,F as n,Ht as r,I as i,O as a,Ot as o,R as s,S as c,_t as l,et as u,j as d,nt as f,o as p,zt as m}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import"./useFeatureFlags-BfqxvwHy.js";import"./api-C840HmAF.js";import"./vendor-markdown-8POvMhty.js";import"./colorUtil-Q3kaA72Z.js";import"./i18n-B8CRKNXU.js";import"./vendor-reka-ui-Dfvl2gA8.js";import{t as h}from"./Button-uSZXZovG.js";import{_r as g}from"./dialogService-J-k0CeI4.js";import"./systemStatsStore-BJOd4X3d.js";import"./userStore-o2bxxBJt.js";import"./useErrorHandling-t4kNWELW.js";import"./vendor-tiptap-BZCaYoPl.js";import"./Popover-BV6_S20i.js";import"./markdownRendererUtil-DH1PCfUd.js";import"./useExternalLink-Cxwyf6Kb.js";var _={class:`flex h-full items-center justify-center p-6`},v={class:`max-w-[100vw] text-center lg:w-[500px]`},y={class:`mb-3 text-xl text-text-primary`},b={class:`mb-5 text-muted`},x={class:`mb-4 rounded bg-secondary-background px-3 py-2 text-left`},S={class:`mb-2 text-sm font-semibold text-text-primary`},C={class:`space-y-1.5 text-sm text-muted`},w={key:0,class:`mb-4 text-left`},T={key:0,class:`mt-2 rounded border-muted-background border p-4 font-mono text-xs text-muted-foreground break-all`},E={class:`mb-5 text-center text-sm text-gray-600`},D={href:`https://support.comfy.org`,class:`cursor-pointer text-blue-400 no-underline`,target:`_blank`,rel:`noopener noreferrer`},O={class:`flex flex-col gap-3`},k=s({__name:`CloudAuthTimeoutView`,props:{errorMessage:{}},setup(e){let s=p(),{logout:k}=g(),A=o(!1),handleRestart=async()=>{await k(),await s.replace({name:`cloud-login`})};return(e,o)=>(u(),d(`div`,_,[a(`div`,v,[a(`h2`,y,r(e.$t(`cloudOnboarding.authTimeout.title`)),1),a(`p`,b,r(e.$t(`cloudOnboarding.authTimeout.message`)),1),a(`div`,x,[a(`h3`,S,r(e.$t(`cloudOnboarding.authTimeout.troubleshooting`)),1),a(`ul`,C,[(u(!0),d(c,null,f(e.$tm(`cloudOnboarding.authTimeout.causes`),(e,t)=>(u(),d(`li`,{key:t,class:`flex gap-2`},[o[1]||=a(`span`,null,`•`,-1),a(`span`,null,r(e),1)]))),128))])]),e.errorMessage?(u(),d(`div`,w,[a(`button`,{class:`flex w-full items-center justify-between rounded bg-secondary-background px-4 py-2 text-sm text-text-secondary transition-colors hover:bg-secondary-background-hover border-0`,onClick:o[0]||=e=>A.value=!A.value},[a(`span`,null,r(e.$t(`cloudOnboarding.authTimeout.technicalDetails`)),1),a(`i`,{class:m([`pi`,A.value?`pi-chevron-up`:`pi-chevron-down`])},null,2)]),A.value?(u(),d(`div`,T,r(e.errorMessage),1)):t(``,!0)])):t(``,!0),a(`p`,E,[n(r(e.$t(`cloudOnboarding.authTimeout.helpText`))+` `,1),a(`a`,D,r(e.$t(`cloudOnboarding.authTimeout.supportLink`)),1),o[2]||=n(`. `)]),a(`div`,O,[i(h,{class:`w-full`,onClick:handleRestart},{default:l(()=>[n(r(e.$t(`cloudOnboarding.authTimeout.restart`)),1)]),_:1})])])]))}});export{k as default};
//# sourceMappingURL=CloudAuthTimeoutView-BXKwAOM-.js.map