const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./ValueControlPopover-DEfcpKva.js","./rolldown-runtime-DIIn1E2Q.js","./vendor-primevue-DyvCA8Nd.js","./vendor-vue-core-IZuWV8u3.js","./dialogService-J-k0CeI4.js","./_plugin-vue_export-helper-D8rLfeal.js","./vendor-other-Q0G0D0d6.js","./vendor-firebase-yTFzdAQf.js","./vendor-three-sFOzKPkM.js","./vendor-tiptap-BZCaYoPl.js","./vendor-reka-ui-Dfvl2gA8.js","./vendor-i18n-NwyZMF0q.js","./vendor-vueuse-ChbGLbpR.js","./vendor-axios-9S3AGag7.js","./vendor-zod-CdZx8tM8.js","./systemStatsStore-BJOd4X3d.js","./vendor-markdown-8POvMhty.js","./api-C840HmAF.js","./vendor-yjs-D82Tykvg.js","./i18n-B8CRKNXU.js","./widget-BXjWUUk7.js","./types-Bc3W4AWd.js","./colorUtil-Q3kaA72Z.js","./src-B0kocU_l.js","./Popover-BV6_S20i.js","./Button-uSZXZovG.js","./SelectValue-BUc_IgwT.js","./useErrorHandling-t4kNWELW.js","./useExternalLink-Cxwyf6Kb.js","./envUtil-DhK5xFg_.js","./useFeatureFlags-BfqxvwHy.js","./telemetry-B10ff63e.js","./userStore-o2bxxBJt.js","./widgetTypes-C7uVk06B.js","./markdownRendererUtil-DH1PCfUd.js","./vendor-other-CaaUC6Qe.css","./dialogService-CRfq7cQX.css"])))=>i.map(i=>d[i]);
import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{lt as t}from"./vendor-primevue-DyvCA8Nd.js";import{D as n,G as r,I as i,K as a,L as o,Lt as s,O as c,Ot as l,R as u,_t as d,et as f,j as p,k as m,ot as h,pt as g,ut as _,zt as v}from"./vendor-vue-core-IZuWV8u3.js";import{t as y}from"./Button-uSZXZovG.js";import{t as b}from"./Popover-BV6_S20i.js";var x={class:`relative grid grid-cols-subgrid`},S=u({__name:`WidgetWithControl`,props:r({widget:{},component:{}},{modelValue:{},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let r=o(()=>t(()=>import(`./ValueControlPopover-DEfcpKva.js`),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36]),import.meta.url)),u=e,S=_(e,`modelValue`),C=l(u.widget.controlWidget.value),w=n(()=>{switch(C.value){case`increment`:return`pi pi-plus`;case`decrement`:return`pi pi-minus`;case`fixed`:return`icon-[lucide--pencil-off]`;default:return`icon-[lucide--shuffle]`}});return g(C,u.widget.controlWidget.update),(e,t)=>(f(),p(`div`,x,[(f(),m(h(e.component),a(e.$attrs,{modelValue:S.value,"onUpdate:modelValue":t[1]||=e=>S.value=e,widget:e.widget}),{default:d(()=>[i(b,null,{button:d(()=>[i(y,{variant:`textonly`,size:`sm`,class:`h-4 w-7 p-0 self-center rounded-xl bg-primary-background/30 hover:bg-primary-background-hover/30`},{default:d(()=>[c(`i`,{class:v(`${w.value} text-primary-background text-xs w-full`)},null,2)]),_:1})]),default:d(()=>[i(s(r),{modelValue:C.value,"onUpdate:modelValue":t[0]||=e=>C.value=e},null,8,[`modelValue`])]),_:1})]),_:1},16,[`modelValue`,`widget`]))]))}});export{S as t};
//# sourceMappingURL=WidgetWithControl-Dxp5CqAu.js.map