import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{D as t,Ht as n,I as r,O as i,R as a,et as o,j as s,ut as c}from"./vendor-vue-core-IZuWV8u3.js";import{t as l}from"./ScrubableNumberInput-CWjM0uhi.js";var u={class:`grid grid-cols-[auto_1fr] gap-x-2 gap-y-1`},d={class:`content-center text-xs text-node-component-slot-text`},f={class:`content-center text-xs text-node-component-slot-text`},p={class:`content-center text-xs text-node-component-slot-text`},m={class:`content-center text-xs text-node-component-slot-text`},h=a({__name:`WidgetBoundingBox`,props:{modelValue:{default:()=>({x:0,y:0,width:512,height:512})},modelModifiers:{}},emits:[`update:modelValue`],setup(e){let a=c(e,`modelValue`),h=t({get:()=>a.value.x,set:e=>{a.value={...a.value,x:e}}}),g=t({get:()=>a.value.y,set:e=>{a.value={...a.value,y:e}}}),_=t({get:()=>a.value.width,set:e=>{a.value={...a.value,width:e}}}),v=t({get:()=>a.value.height,set:e=>{a.value={...a.value,height:e}}});return(e,t)=>(o(),s(`div`,u,[i(`label`,d,n(e.$t(`boundingBox.x`)),1),r(l,{modelValue:h.value,"onUpdate:modelValue":t[0]||=e=>h.value=e,min:0,step:1},null,8,[`modelValue`]),i(`label`,f,n(e.$t(`boundingBox.y`)),1),r(l,{modelValue:g.value,"onUpdate:modelValue":t[1]||=e=>g.value=e,min:0,step:1},null,8,[`modelValue`]),i(`label`,p,n(e.$t(`boundingBox.width`)),1),r(l,{modelValue:_.value,"onUpdate:modelValue":t[2]||=e=>_.value=e,min:1,step:1},null,8,[`modelValue`]),i(`label`,m,n(e.$t(`boundingBox.height`)),1),r(l,{modelValue:v.value,"onUpdate:modelValue":t[3]||=e=>v.value=e,min:1,step:1},null,8,[`modelValue`])]))}});export{h as t};
//# sourceMappingURL=WidgetBoundingBox-BhECxXw3.js.map