import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DyvCA8Nd.js";import"./vendor-firebase-yTFzdAQf.js";import{F as t,Ht as n,I as r,Lt as i,O as a,R as o,S as s,_t as c,et as l,j as u,rt as d,t as f}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import"./useFeatureFlags-BfqxvwHy.js";import"./api-C840HmAF.js";import"./vendor-markdown-8POvMhty.js";import"./colorUtil-Q3kaA72Z.js";import{n as p}from"./vendor-i18n-NwyZMF0q.js";import"./i18n-B8CRKNXU.js";import"./vendor-reka-ui-Dfvl2gA8.js";import{t as m}from"./Button-uSZXZovG.js";import"./dialogService-J-k0CeI4.js";import"./systemStatsStore-BJOd4X3d.js";import{t as h}from"./_plugin-vue_export-helper-D8rLfeal.js";import"./userStore-o2bxxBJt.js";import"./useErrorHandling-t4kNWELW.js";import"./vendor-tiptap-BZCaYoPl.js";import"./Popover-BV6_S20i.js";import"./markdownRendererUtil-DH1PCfUd.js";import"./useExternalLink-Cxwyf6Kb.js";import{t as g}from"./GlobalToast-BabUPyBB.js";import{t as _}from"./BaseViewTemplate-jYb705NA.js";var v=``+new URL(`thumbnail-imMA3y7Z.png`,import.meta.url).href,y=``+new URL(`video-BvOHf4P9.mp4`,import.meta.url).href,b=``+new URL(`images/comfy-cloud-logo.svg`,import.meta.url).href,x={},S={class:`mx-auto flex h-[7%] max-h-[70px] w-5/6 items-end`},C=[`alt`];function _sfc_render(e,t){return l(),u(`div`,S,[a(`img`,{src:b,alt:e.$t(`subscription.comfyCloudLogo`),class:`h-3/4 max-h-10 w-auto`},null,8,C)])}var w=h(x,[[`render`,_sfc_render]]),T={class:`mx-auto flex h-[5%] max-h-[60px] w-5/6 items-start gap-2.5`},E={href:`https://www.comfy.org/terms-of-service`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},D={href:`https://www.comfy.org/privacy-policy`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},O={href:`https://support.comfy.org`,class:`cursor-pointer text-sm text-gray-600 no-underline`,target:`_blank`,rel:`noopener noreferrer`},k=o({__name:`CloudTemplateFooter`,setup(e){let{t}=p();return(e,r)=>(l(),u(`footer`,T,[a(`a`,E,n(i(t)(`auth.login.termsLink`)),1),a(`a`,D,n(i(t)(`auth.login.privacyLink`)),1),a(`a`,O,n(i(t)(`cloudFooter_needHelp`)),1)]))}}),A={class:`flex`},j={class:`relative hidden flex-1 overflow-hidden bg-black lg:block`},M=[`poster`],N=[`src`],P={class:`absolute inset-0 flex items-center justify-center text-center text-white`},F={class:`font-abcrom hero-title font-black uppercase italic`},I={class:`m-2 text-center text-xl text-white`},L={class:`m-0 text-center text-xl text-white`},R={class:`absolute inset-0 flex flex-col justify-end px-14 pb-[64px]`},z={class:`flex items-center justify-end`},B={class:`flex items-center gap-3`},V={class:`text-md text-white`},H=o({__name:`CloudTemplate`,setup(e){let{t:o}=p(),handleDownloadClick=()=>{window.open(`https://www.comfy.org/download`,`_blank`)};return(e,s)=>(l(),u(`div`,A,[r(_,{dark:``,class:`flex-1`},{header:c(()=>[r(w)]),footer:c(()=>[r(k)]),default:c(()=>[d(e.$slots,`default`)]),_:3}),a(`div`,j,[a(`video`,{class:`absolute inset-0 h-full w-full object-cover`,autoplay:``,muted:``,loop:``,playsinline:``,poster:i(v)},[a(`source`,{src:i(y),type:`video/mp4`},null,8,N)],8,M),s[0]||=a(`div`,{class:`absolute inset-0 h-full w-full bg-black/30`},null,-1),a(`div`,P,[a(`div`,null,[a(`h1`,F,n(i(o)(`cloudStart_title`)),1),a(`p`,I,n(i(o)(`cloudStart_desc`)),1),a(`p`,L,n(i(o)(`cloudStart_explain`)),1)])]),a(`div`,R,[a(`div`,z,[a(`div`,B,[a(`p`,V,n(i(o)(`cloudStart_wantToRun`)),1),r(m,{type:`button`,class:`h-10 bg-black font-bold text-white`,variant:`secondary`,onClick:handleDownloadClick},{default:c(()=>[t(n(i(o)(`cloudStart_download`)),1)]),_:1})])])])])]))}}),U=o({__name:`CloudLayoutView`,setup(e){return(e,t)=>(l(),u(s,null,[r(H,null,{default:c(()=>[r(i(f))]),_:1}),r(g)],64))}});export{U as default};
//# sourceMappingURL=CloudLayoutView-DIowPagF.js.map