import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{A as t,F as n,Ht as r,Lt as i,O as a,R as o,S as s,b as c,et as l,j as u,rt as d,zt as f}from"./vendor-vue-core-IZuWV8u3.js";import{t as p}from"./src-B0kocU_l.js";import{r as m}from"./widgetTypes-C7uVk06B.js";var h={class:`grid grid-cols-subgrid min-w-0 justify-between gap-1 text-node-component-slot-text`},g={key:0,class:`truncate content-center-safe`},_={class:`relative min-w-0 flex-1`},v=o({__name:`WidgetLayoutField`,props:{widget:{}},setup(e){let o=m();return(e,m)=>(l(),u(`div`,h,[i(o)?t(``,!0):(l(),u(`div`,g,[e.widget.name?(l(),u(s,{key:0},[n(r(e.widget.label||e.widget.name),1)],64)):t(``,!0)])),a(`div`,_,[a(`div`,{class:f(i(p)(`cursor-default min-w-0 rounded-lg focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all`,e.widget.borderStyle)),onPointerdown:m[0]||=c(()=>{},[`stop`]),onPointermove:m[1]||=c(()=>{},[`stop`]),onPointerup:m[2]||=c(()=>{},[`stop`])},[d(e.$slots,`default`)],34)])]))}});export{v as t};
//# sourceMappingURL=WidgetLayoutField-RcWi6XR8.js.map