import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-DyvCA8Nd.js";import"./vendor-firebase-yTFzdAQf.js";import"./vendor-other-Q0G0D0d6.js";import"./useFeatureFlags-BfqxvwHy.js";import"./api-C840HmAF.js";import"./vendor-markdown-8POvMhty.js";import"./colorUtil-Q3kaA72Z.js";import{o as t}from"./i18n-B8CRKNXU.js";import"./vendor-reka-ui-Dfvl2gA8.js";import"./Button-uSZXZovG.js";import{yn as n}from"./dialogService-J-k0CeI4.js";import"./systemStatsStore-BJOd4X3d.js";import"./userStore-o2bxxBJt.js";import"./useErrorHandling-t4kNWELW.js";import"./vendor-tiptap-BZCaYoPl.js";import"./Popover-BV6_S20i.js";import"./markdownRendererUtil-DH1PCfUd.js";import"./useExternalLink-Cxwyf6Kb.js";import{r,t as i}from"./config-CZLvPB8A.js";var a=`https://support.comfy.org/hc/en-us/requests/new`,o=`43066738713236`,s=r(),c=`${a}?${new URLSearchParams({ticket_form_id:o,[i.DISTRIBUTION]:s}).toString()}`,l=[{icon:`icon-[lucide--message-circle-question-mark]`,label:t(`actionbar.feedback`),tooltip:t(`actionbar.feedbackTooltip`),onClick:()=>{window.open(c,`_blank`,`noopener,noreferrer`)}}];n().registerExtension({name:`Comfy.Cloud.FeedbackButton`,actionBarButtons:l});
//# sourceMappingURL=cloudFeedbackTopbarButton-DoX8BgHZ.js.map