import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{D as t,F as n,Ht as r,O as i,R as a,_t as o,at as s,et as c,k as l,vt as u}from"./vendor-vue-core-IZuWV8u3.js";import{t as d}from"./types-Bc3W4AWd.js";import{c as f,r as p}from"./vendor-vueuse-ChbGLbpR.js";import{n as m}from"./vendor-i18n-NwyZMF0q.js";import{t as h}from"./telemetry-B10ff63e.js";import{t as g}from"./Button-uSZXZovG.js";import{vr as _}from"./dialogService-J-k0CeI4.js";var v=a({__name:`SubscribeToRun`,setup(e){let{t:a}=m(),v=f(p).greaterOrEqual(`md`),y=t(()=>v.value?a(`subscription.subscribeToRunFull`):a(`subscription.subscribeToRun`)),{showSubscriptionDialog:b}=_(),handleSubscribeToRun=()=>{d&&h()?.trackRunButton({subscribe_to_run:!0}),b()};return(e,t)=>{let a=s(`tooltip`);return u((c(),l(g,{class:`subscribe-to-run-button whitespace-nowrap`,variant:`primary`,size:`sm`,style:{background:`var(--color-subscription-button-gradient)`,color:`var(--color-white)`,borderColor:`transparent`},"data-testid":`subscribe-to-run-button`,onClick:handleSubscribeToRun},{default:o(()=>[t[0]||=i(`i`,{class:`pi pi-lock`},null,-1),n(` `+r(y.value),1)]),_:1})),[[a,{value:e.$t(`subscription.subscribeToRunFull`),showDelay:600},void 0,{bottom:!0}]])}}});export{v as t};
//# sourceMappingURL=SubscribeToRun-t6EmLBLg.js.map