import"./vendor-primevue-DyvCA8Nd.js";import"./vendor-firebase-yTFzdAQf.js";import"./vendor-other-Q0G0D0d6.js";import"./useFeatureFlags-BfqxvwHy.js";import"./api-C840HmAF.js";import"./vendor-markdown-8POvMhty.js";import"./colorUtil-Q3kaA72Z.js";import"./i18n-B8CRKNXU.js";import"./vendor-reka-ui-Dfvl2gA8.js";import"./Button-uSZXZovG.js";import"./dialogService-J-k0CeI4.js";import"./systemStatsStore-BJOd4X3d.js";import"./userStore-o2bxxBJt.js";import"./useErrorHandling-t4kNWELW.js";import"./vendor-tiptap-BZCaYoPl.js";import"./Popover-BV6_S20i.js";import"./markdownRendererUtil-DH1PCfUd.js";import"./useExternalLink-Cxwyf6Kb.js";import"./vendor-three-sFOzKPkM.js";import"./Load3DControls-C3IYHaIj.js";import"./constants-Mwe9lPjD.js";import"./Load3dViewerContent-BY8aoGY0.js";import{t as e}from"./Load3D-RC0Sgd06.js";import"./AnimationControls-DxEslbHX.js";import"./load3dService-D05IgI3_.js";import"./useLoad3dViewer-BRJXoRXk.js";import"./useLoad3d-CLSKV0ES.js";export{e as default};