import"./vendor-primevue-DyvCA8Nd.js";import"./vendor-other-Q0G0D0d6.js";import"./api-C840HmAF.js";import"./vendor-markdown-8POvMhty.js";import"./colorUtil-Q3kaA72Z.js";import"./i18n-B8CRKNXU.js";import{n as e,r as t,t as n}from"./auth-DklPGlJO.js";export{n as getSurveyCompletedStatus};