import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{A as t,D as n,F as r,Ht as i,I as a,K as o,R as s,_t as c,et as l,j as u,zt as d}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import"./vendor-reka-ui-Dfvl2gA8.js";import{t as f}from"./Button-uSZXZovG.js";import{o as p,t as m}from"./widgetPropFilter-BW8CLrhL.js";var h={class:`flex flex-col gap-1`},g=s({__name:`WidgetButton`,props:{widget:{}},setup(e){let s=e,g=[...m,`iconClass`],_=n(()=>p(s.widget.options,g)),handleClick=()=>{s.widget.callback&&s.widget.callback()};return(e,n)=>(l(),u(`div`,h,[a(f,o({class:`text-base-foreground w-full border-0 bg-component-node-widget-background p-2`,"aria-label":e.widget.label,size:`sm`,variant:`textonly`},_.value,{onClick:handleClick}),{default:c(()=>[r(i(e.widget.label??e.widget.name)+` `,1),e.widget.options?.iconClass?(l(),u(`i`,{key:0,class:d(e.widget.options.iconClass)},null,2)):t(``,!0)]),_:1},16,[`aria-label`])]))}});export{g as default};
//# sourceMappingURL=WidgetButton-okEnJhgN.js.map