import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{Lt as t,O as n,Ot as r,R as i,Z as a,et as o,j as s,q as c,rt as l,v as u,vt as d,zt as f}from"./vendor-vue-core-IZuWV8u3.js";import{n as p}from"./types-Bc3W4AWd.js";import{n as m,t as h}from"./envUtil-DhK5xFg_.js";var g={class:`flex w-full grow items-center justify-center overflow-auto`},_=i({__name:`BaseViewTemplate`,props:{dark:{type:Boolean,default:!1}},setup(e){let i={color:`rgba(0, 0, 0, 0)`,symbolColor:`#d4d4d4`},_={color:`rgba(0, 0, 0, 0)`,symbolColor:`#171717`},v=r(null);return a(async()=>{p&&(await c(),h().changeTheme({...e.dark?i:_,height:v.value?.getBoundingClientRect().height??0}))}),(e,r)=>(o(),s(`div`,{class:f([`flex h-svh w-screen flex-col font-sans`,[e.dark?`dark-theme bg-neutral-900 text-neutral-300`:`bg-neutral-300 text-neutral-900`]])},[d(n(`div`,{ref_key:`topMenuRef`,ref:v,class:`app-drag h-(--comfy-topbar-height) w-full`},null,512),[[u,t(m)()]]),n(`div`,g,[l(e.$slots,`default`)])],2))}});export{_ as t};
//# sourceMappingURL=BaseViewTemplate-jYb705NA.js.map