import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{it as t}from"./vendor-primevue-DyvCA8Nd.js";import{D as n,G as r,I as i,K as a,Lt as o,R as s,_t as c,et as l,k as u,ut as d}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import{t as f}from"./src-B0kocU_l.js";import{o as p,r as m}from"./widgetPropFilter-BW8CLrhL.js";import{t as h}from"./layout--1YiVcXi.js";import{t as g}from"./WidgetLayoutField-RcWi6XR8.js";var _=s({__name:`WidgetInputText`,props:r({widget:{}},{modelValue:{default:``},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let r=e,s=d(e,`modelValue`),_=n(()=>p(r.widget.options,m));return(e,n)=>(l(),u(g,{widget:e.widget},{default:c(()=>[i(o(t),a({modelValue:s.value,"onUpdate:modelValue":n[0]||=e=>s.value=e},_.value,{class:o(f)(o(h),`w-full text-xs py-2 px-4`),"aria-label":e.widget.name,size:`small`,pt:{root:`truncate min-w-[4ch]`}}),null,16,[`modelValue`,`class`,`aria-label`])]),_:1},8,[`widget`]))}});export{_ as default};
//# sourceMappingURL=WidgetInputText-BqE9xWJK.js.map