import{r as e}from"./rolldown-runtime-DIIn1E2Q.js";import{i as t,n}from"./vendor-primevue-DyvCA8Nd.js";import"./vendor-firebase-yTFzdAQf.js";import{F as r,Ht as i,I as a,Lt as o,Ot as s,R as c,_t as l,et as u,k as d}from"./vendor-vue-core-IZuWV8u3.js";import"./vendor-other-Q0G0D0d6.js";import"./useFeatureFlags-BfqxvwHy.js";import"./api-C840HmAF.js";import"./vendor-markdown-8POvMhty.js";import"./colorUtil-Q3kaA72Z.js";import"./i18n-B8CRKNXU.js";import"./vendor-reka-ui-Dfvl2gA8.js";import{t as f}from"./Button-uSZXZovG.js";import{_r as p}from"./dialogService-J-k0CeI4.js";import"./systemStatsStore-BJOd4X3d.js";import"./userStore-o2bxxBJt.js";import"./useErrorHandling-t4kNWELW.js";import"./vendor-tiptap-BZCaYoPl.js";import"./Popover-BV6_S20i.js";import"./markdownRendererUtil-DH1PCfUd.js";import"./useExternalLink-Cxwyf6Kb.js";import{i as m}from"./signInSchema-BMYA3BDA.js";import{t as h}from"./PasswordFields-D0_uh31-.js";var g=c({__name:`UpdatePasswordContent`,props:{onSuccess:{type:Function}},setup(e){let c=p(),g=s(!1),onSubmit=async t=>{if(t.valid){g.value=!0;try{await c.updatePassword(t.values.password),e.onSuccess()}finally{g.value=!1}}};return(e,s)=>(u(),d(o(t),{class:`flex w-96 flex-col gap-6`,resolver:o(n)(o(m)),onSubmit},{default:l(()=>[a(h),a(f,{type:`submit`,class:`mt-4 h-10 font-medium`,loading:g.value},{default:l(()=>[r(i(e.$t(`userSettings.updatePassword`)),1)]),_:1},8,[`loading`])]),_:1},8,[`resolver`]))}});export{g as default};
//# sourceMappingURL=UpdatePasswordContent-BiE-azID.js.map